==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let PolarLineSeries = /*@__PURE__*/ (() => {
    class PolarLineSeries extends PolarLineSeriesBase {
        get_ex() {
            return true;
        }
        cg() {
            return new PolarLineSeriesView(this);
        }
        o0(a) {
            super.o0(a);
            this.zm = a;
        }
        constructor() {
            super();
            this.ab = PolarLineSeries.$;
        }
        zk(a) {
            let b = a;
            b.c8();
        }
        zl(a, b) {
            let c = b;
            c.c9(a.m, this.hj);
            this.v3.az(this, this.wq(), runOn(this, this.vg));
            let d = false;
            let e = this.v3.b;
            if (e != null) {
                d = true;
            }
            if (d) {
                this.x5(-1, this.wc.count, b.q);
            }
            this.v3.ad(b.db, true, false, true, false);
        }
        zc() {
            return this.zn;
        }
        o8(a, b, c, d) {
            super.o8(a, b, c, d);
            switch (b) {
                case PolarLineSeries.$$p[0]:
                    this.pp(false);
                    this.ol();
                    break;
            }
        }
    }
    PolarLineSeries.$t = /*@__PURE__*/ markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zn:zp', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
})();
/**
 * @hidden
 */
export let PolarLineSeriesView = /*@__PURE__*/ (() => {
    class PolarLineSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c7 = null;
            this.db = new Path();
            this.da = new Path();
            this.c7 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ua = Defaults.e;
            }
        }
        c8() {
            this.db.an = null;
            this.da.an = null;
            this.as();
        }
        c9(a, b) {
            this.c7.y9.d(this.db, a, b);
            this.as();
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            let a = this.br();
            this.da.an = this.db.an;
            this.da._stroke = a;
            this.da.ad = this.e.hk + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.da);
                }
                else {
                    a.t(this.db);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.a9.exportPathData(a, this.db, "polarShape", ["Main"]);
        }
    }
    PolarLineSeriesView.$t = /*@__PURE__*/ markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let PolarLineSeries = /*@__PURE__*/ (() => {
    class PolarLineSeries extends PolarLineSeriesBase {
        bj() {
            return new PolarLineSeries();
        }
        get_fj() {
            return true;
        }
        cr() {
            return new PolarLineSeriesView(this);
        }
        qz(a) {
            super.qz(a);
            this.acp = a;
        }
        constructor() {
            super();
            this.ab = PolarLineSeries.$;
        }
        acn(a) {
            let b = a;
            b.da();
        }
        aco(a, b) {
            let c = b;
            c.db(a.m, this.ic);
            this.y0.az(this, this.zs(), runOn(this, this.yi));
            let d = false;
            let e = this.y0.b;
            if (e != null) {
                d = true;
            }
            if (d) {
                this.aa7(-1, this.ze.count, b.q);
            }
            this.y0.ad(b.dd, true, false, true, false);
        }
        acf() {
            return this.acq;
        }
        q7(a, b, c, d) {
            super.q7(a, b, c, d);
            switch (b) {
                case PolarLineSeries.$$p[0]:
                    this.rp(false);
                    this.qj();
                    break;
            }
        }
    }
    PolarLineSeries.$t = /*@__PURE__*/ markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acq:acs', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
})();
/**
 * @hidden
 */
export let PolarLineSeriesView = /*@__PURE__*/ (() => {
    class PolarLineSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c9 = null;
            this.dd = new Path();
            this.dc = new Path();
            this.c9 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.w5 = Defaults.e;
            }
        }
        da() {
            this.dd.an = null;
            this.dc.an = null;
            this.as();
        }
        db(a, b) {
            this.c9.acc.d(this.dd, a, b);
            this.as();
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            let a = this.br();
            this.dc.an = this.dd.an;
            this.dc._stroke = a;
            this.dc.ad = this.e.id + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dc);
                }
                else {
                    a.t(this.dd);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPathData(a, this.dd, "polarShape", ["Main"]);
        }
    }
    PolarLineSeriesView.$t = /*@__PURE__*/ markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
})();
